## 1.2.1

`2022-08-23`

- 🐞 修复流程图 `canvasProps.config` 配置无效

## 1.2.0

`2022-08-16`

- 🔥 新增 canvasProps.showPortsOnNodeSelected 属性，支持选中节点时连线
- 🔥 新增 canvasProps.edgeConfig 属性，支持默认连线配置

## 1.1.9

`2022-07-26`

- 🐞 [新建边无反应](https://github.com/ant-design/ant-design-charts/issues/1455)

## 1.1.8

`2022-07-19`

- 🐞 [Critical security vulnerabilities immer](https://github.com/ant-design/ant-design-charts/issues/1289)

